<?php

namespace Modules\CustomFields\Http\ViewComposers;

use Illuminate\View\View;
use Modules\CustomFields\Models\Field;
use Modules\CustomFields\Models\FieldValue;
use Modules\CustomFields\Models\Location;

class DocumentItems
{
    static $item_count = 0;

    /**
     * Bind data to the view.
     *
     * @param  View  $view
     * @return void
     */
    public function compose(View $view)
    {
        // No need to add suggestions in console
        if (app()->runningInConsole() || !env('APP_INSTALLED')) {
            return;
        }

        // Set Document
        if (array_key_exists('invoice', $view->getData())) {
            $location = Location::where('code', 'sales.invoices')->first();
        } else {
            $location = Location::where('code', 'purchases.bills')->first();
        }

        $custom_fields = Field::enabled()->orderBy('name')->byLocation($location->id)->get();

        $invoice_item = $view->getData()['item'];

        foreach ($custom_fields as $custom_field) {
            if (!strpos($custom_field->fieldLocation->sort_order, 'td')) {
                continue;
            }
            
            $file_type_value = '';
            
            $field_value = FieldValue::record($invoice_item->id, get_class($invoice_item))->where('field_id', $custom_field->id)->first();
            
            switch ($custom_field->type->type) {
                case 'select':
                case 'radio':
                    $field_type_options  = $custom_field->fieldTypeOption->pluck('value', 'id');
    
                    if (isset($field_type_options[$field_value->value])) {
                        $file_type_value = $field_type_options[$field_value->value];
                    }
    
                    break;
                case 'checkbox':
                    $field_type_options  = $custom_field->fieldTypeOption;
    
                    if (isset($field_type_options[(int) $field_value->value])) {
                        $file_type_value = $field_type_options[(int) $field_value->value];
                    }
    
                    break;
                case 'text':
                case 'date':
                case 'time':
                case 'date&time':
                case 'textarea':
                    $file_type_value = $field_value->value;
    
                    break;
            }
            
            $sort_order = $custom_field->fieldLocation->sort_order;
            $sort_orders = explode('_td_input', $sort_order);
            $table_name = $sort_orders[0] . '_td' . $sort_orders[1];

            if (version_compare(version('short'), '2.0.23', '>=')) {
                if (static::$item_count > 0) {
                    $view->getFactory()->flushStack($sort_orders[0] . '_th' . $sort_orders[1]);
                    $view->getFactory()->flushStack($table_name);
                }
            }

            $view->getFactory()->startPush($table_name, view('custom-fields::invoices.item_td', compact('file_type_value')));
        }

        static::$item_count++;
    }
}
