<?php

namespace Modules\CustomFields\Http\ViewComposers;

use Illuminate\View\View;
use Modules\CustomFields\Traits\CustomFields;
use Modules\CustomFields\Traits\Permissions;

class Field
{
    use CustomFields, Permissions;

    /**
     * Bind data to the view.
     *
     * @param  View  $view
     * @return void
     */
    public function compose(View $view)
    {
        if ($this->canCompose()) {
            return;
        }

        $request = request();

        $fields = $this->getFieldsByLocation($request->segment(1) . '.' . $request->segment(2));

        if ($fields->isEmpty()) {
            return;
        }

        foreach ($fields as $field) {
            $input_col = $field->class;
            $input_type = $field->type->type . 'Group';

            if ($field->type->type == 'checkbox') {
                $input_options = $field->fieldTypeOption()->get();
            } else {
                $input_options = $field->fieldTypeOption->pluck('value', 'id');
            }
            
            if ($field->fieldLocation->sort_order == 'item_custom_fields') {
                $input_attributes = $this->getInputAttributesForItems($field);
                $input_values = $this->getInputValuesForItems($field, $request);

                $view->getFactory()->startPush('scripts', view('custom-fields::partials.script', compact('field', 'input_values')));
                $input_values = null;
            } else {
                $input_attributes = $this->getInputAttributes($field);
                $input_values = $this->getInputValues($field, $request);
            }

            $view->getFactory()->startPush($field->fieldLocation->sort_order, view('custom-fields::field', compact('field', 'input_type', 'input_attributes', 'input_col', 'input_options', 'input_values')));
        }
    }
}
