<?php

namespace Modules\CustomFields\Observers\Document;

use App\Abstracts\Observer;
use App\Models\Document\DocumentItem as Model;
use Modules\CustomFields\Models\FieldValue;
use Modules\CustomFields\Traits\CustomFields;

class DocumentItem extends Observer
{
    use CustomFields;

    static $document_item_count = 0;

    /**
     * Listen to the created event.
     *
     * @param  Model $document_item
     *
     * @return void
     */
    public function created(Model $document_item)
    {
        if ($document_item->type == 'invoice') {
            $custom_fields = $this->getFieldsByLocation('sales.invoices');
        } else {
            $custom_fields = $this->getFieldsByLocation('purchases.bills');
        }

        $request = request();

        foreach ($custom_fields as $custom_field) {
            if ($custom_field->fieldLocation->sort_order != 'item_custom_fields') {
                continue;
            }

            $value = null;

            if (isset($request['items'][static::$document_item_count][$custom_field->code])) {
                $value = $request['items'][static::$document_item_count][$custom_field->code];
            }

            FieldValue::create([
                'company_id' => session('company_id'),
                'field_id' => $custom_field->id,
                'type_id' => $custom_field->type_id,
                'type' => $custom_field->type->type,
                'location_id' => $custom_field->locations,
                'model_id' => $document_item->id,
                'model_type' => get_class($document_item),
                'value' => $value,
            ]);

            static::$document_item_count++;
        }
    }

    /**
     * Listen to the deleted event.
     *
     * @param  Model $document_item
     *
     * @return void
     */
    public function deleted(Model $document_item)
    {
        FieldValue::record($document_item->id, get_class($document_item))->delete();
    }
}
