<?php

namespace Modules\CustomFields\Observers\Sale;

use App\Abstracts\Observer;
use App\Models\Sale\InvoiceItem as Model;
use Modules\CustomFields\Models\FieldValue;
use Modules\CustomFields\Traits\CustomFields;

class InvoiceItem extends Observer
{
    use CustomFields;

    static $invoice_item_count = 0;

    /**
     * Listen to the created event.
     *
     * @param  Model $invoice_item
     *
     * @return void
     */
    public function created(Model $invoice_item)
    {
        $custom_fields = $this->getFieldsByLocation('sales.invoices');

        $request = request();

        foreach ($custom_fields as $custom_field) {
            if (strpos($custom_field->fieldLocation->sort_order, 'td') === false) {
                continue;
            }

            $value = null;

            if (isset($request['items'][static::$invoice_item_count][$custom_field->code])) {
                $value = $request['items'][static::$invoice_item_count][$custom_field->code];
            }

            $custom_field_value = FieldValue::create([
                'company_id' => session('company_id'),
                'field_id' => $custom_field->id,
                'type_id' => $custom_field->type_id,
                'type' => $custom_field->type->type,
                'location_id' => $custom_field->locations,
                'model_id' => $invoice_item->id,
                'model_type' => get_class($invoice_item),
                'value' => $value,
            ]);

            static::$invoice_item_count++;
        }
    }

    /**
     * Listen to the deleted event.
     *
     * @param  Model $invoice_item
     *
     * @return void
     */
    public function deleted(Model $invoice_item)
    {
        FieldValue::record($invoice_item->id, get_class($invoice_item))->delete();
    }
}
